@@ -5,6 +5,7 @@ import pyperclip
 import requests
 import websockets
 from websockets import InvalidStatus
+from rapidfuzz import fuzz
 
 from GameSentenceMiner.util.gsm_utils import do_text_replacements, TEXT_REPLACEMENTS_FILE, run_new_thread
 from GameSentenceMiner.util.configuration import *
@@ -14,9 +15,15 @@ from GameSentenceMiner.web.texthooking_page import add_event_to_texthooker, send
 if get_config().wip.overlay_websocket_send:
     import GameSentenceMiner.wip.get_overlay_coords as get_overlay_coords
 
+
 current_line = ''
 current_line_after_regex = ''
 current_line_time = datetime.now()
+# Track the start time for the current sequence
+current_sequence_start_time = None
+# Track the last raw clipboard text for prefix comparison
+last_raw_clipboard = ''
+timer = None
 
 last_clipboard = ''
 
@@ -84,8 +91,12 @@ async def listen_websockets():
                                 line_time = datetime.fromisoformat(data["time"])
                         except json.JSONDecodeError or TypeError:
                             current_clipboard = message
+                        logger.info
                         if current_clipboard != current_line:
-                            await handle_new_text_event(current_clipboard, line_time if line_time else None)
+                            try:
+                                await handle_new_text_event(current_clipboard, line_time if line_time else None)
+                            except Exception as e: 
+                                logger.error(f"Error handling new text event: {e}", exc_info=True)
             except (websockets.ConnectionClosed, ConnectionError, InvalidStatus, ConnectionResetError, Exception) as e:
                 if websocket_url in gsm_status.websockets_connected:
                     gsm_status.websockets_connected.remove(websocket_url)
@@ -112,26 +123,75 @@ async def listen_websockets():
     websocket_tasks.append(listen_on_websocket(f"localhost:{get_config().advanced.ocr_websocket_port}"))
 
     await asyncio.gather(*websocket_tasks)
+    
+    
+async def merge_sequential_lines(line, start_time=None):
+    if not get_config().general.merge_matching_sequential_text:
+        return
+    logger.info(f"Merging Sequential Lines: {line}")
+    # Use the sequence start time for the merged line
+    await add_line_to_text_log(line, start_time if start_time else datetime.now())
+    timer = None
+    # Reset sequence tracking
+    current_sequence_start_time = None
+    last_raw_clipboard = ''
+    
+def schedule_merge(wait, coro, args):
+    async def wrapper():
+        await asyncio.sleep(wait)
+        await coro(*args)
+    task = asyncio.create_task(wrapper())
+    return task
+
 
 async def handle_new_text_event(current_clipboard, line_time=None):
-    global current_line, current_line_time, current_line_after_regex
+    global current_line, current_line_time, current_line_after_regex, timer, current_sequence_start_time, last_raw_clipboard
     current_line = current_clipboard
-    if get_config().general.texthook_replacement_regex:
-        current_line_after_regex = re.sub(get_config().general.texthook_replacement_regex, '', current_line)
+    logger.info(f"Current Line: {current_line} last raw clipboard: {last_raw_clipboard}")
+    # Only apply this logic if merging is enabled
+    if get_config().general.merge_matching_sequential_text:
+        logger.info(f"Handling new text event: {current_line}")
+        # If no timer is active, this is the start of a new sequence
+        if not timer:
+            logger.info("Starting a new sequence of text lines.")
+            current_sequence_start_time = line_time if line_time else datetime.now()
+            last_raw_clipboard = current_line
+            # Start the timer
+            timer = schedule_merge(2, merge_sequential_lines, [current_line[:], current_sequence_start_time])
+        else:
+            # If the new text starts with the previous, reset the timer (do not update start time)
+            if current_line.startswith(last_raw_clipboard) or fuzz.ratio(current_line, last_raw_clipboard) > 50:
+                logger.info(f"Current line starts with last raw clipboard: {current_line} starts with {last_raw_clipboard}")
+                last_raw_clipboard = current_line
+                timer.cancel()
+                timer = schedule_merge(2, merge_sequential_lines, [current_line[:], current_sequence_start_time])
+            else:
+                logger.info(f"Current line does not start with last raw clipboard: {current_line} does not start with {last_raw_clipboard}")
+                # If not a prefix, treat as a new sequence
+                # timer.cancel()
+                current_sequence_start_time = line_time if line_time else datetime.now()
+                last_raw_clipboard = current_line
+                timer = schedule_merge(2, merge_sequential_lines, [current_line[:], current_sequence_start_time])
     else:
-        current_line_after_regex = current_line
-    current_line_after_regex = do_text_replacements(current_line, TEXT_REPLACEMENTS_FILE)
+        await add_line_to_text_log(current_line, line_time)
+
+                
+async def add_line_to_text_log(line, line_time=None):
+    if get_config().general.texthook_replacement_regex:
+        current_line_after_regex = re.sub(get_config().general.texthook_replacement_regex, '', line)
+    else:
+        current_line_after_regex = line
+    current_line_after_regex = do_text_replacements(current_line_after_regex, TEXT_REPLACEMENTS_FILE)
     logger.info(f"Line Received: {current_line_after_regex}")
     current_line_time = line_time if line_time else datetime.now()
     gsm_status.last_line_received = current_line_time.strftime("%Y-%m-%d %H:%M:%S")
-    add_line(current_line_after_regex, line_time)
+    add_line(current_line_after_regex, line_time if line_time else datetime.now())
     if len(get_text_log().values) > 0:
         await add_event_to_texthooker(get_text_log()[-1])
     if get_config().wip.overlay_websocket_port and get_config().wip.overlay_websocket_send and overlay_server_thread.has_clients():
         boxes = await find_box_for_sentence(current_line_after_regex)
         if boxes:
             await send_word_coordinates_to_overlay(boxes)
-    
 
 async def find_box_for_sentence(sentence):
     boxes = []
