@@ -12,6 +12,7 @@ from GameSentenceMiner.util.communication.send import send_restart_signal
 from GameSentenceMiner.util.downloader.download_tools import download_obs_if_needed, download_ffmpeg_if_needed
 from GameSentenceMiner.vad import vad_processor
 from GameSentenceMiner.util.model import VADResult
+import time
 
 try:
     import os.path
@@ -45,7 +46,6 @@ try:
     from GameSentenceMiner.web.texthooking_page import run_text_hooker_page
 except Exception as e:
     from GameSentenceMiner.util.configuration import logger, is_linux, is_windows
-    import time
     logger.info("Something bad happened during import/initialization, closing in 5 seconds")
     logger.exception(e)
     time.sleep(5)
@@ -545,6 +545,8 @@ def async_loop():
             await check_obs_folder_is_correct()
         logger.info("Post-Initialization started.")
         vad_processor.init()
+        # if is_beangate:
+            # await run_test_code()
 
     asyncio.run(loop())
 
@@ -577,6 +579,13 @@ async def register_scene_switcher_callback():
             update_icon()
 
     await obs.register_scene_change_callback(scene_switcher_callback)
+    
+async def run_test_code():
+    if get_config().wip.overlay_websocket_port and get_config().wip.overlay_websocket_send:
+        boxes = await gametext.find_box_for_sentence("ちぇっ少しなの？")
+        if boxes:
+            await texthooking_page.send_word_coordinates_to_overlay(boxes)
+        await asyncio.sleep(2)
 
 async def async_main(reloading=False):
     global root, settings_window
