@@ -3,6 +3,8 @@ import os.path
 import subprocess
 import threading
 import time
+from pprint import pprint
+
 import psutil
 
 import obsws_python as obs
@@ -334,6 +336,7 @@ async def register_scene_change_callback(callback):
 
         logger.info("Scene change callback registered.")
 
+
 def get_screenshot(compression=-1):
     try:
         screenshot = os.path.join(configuration.get_temporary_directory(), make_unique_file_name('screenshot.png'))
@@ -355,9 +358,9 @@ def get_screenshot(compression=-1):
         logger.error(f"Error getting screenshot: {e}")
         return None
 
-def get_screenshot_base64(compression=0, width=None, height=None):
+def get_screenshot_base64(compression=75, width=None, height=None):
     try:
-        # update_current_game()
+        update_current_game()
         current_game = get_current_game()
         if not current_game:
             logger.error("No active game scene found.")
@@ -367,7 +370,11 @@ def get_screenshot_base64(compression=0, width=None, height=None):
         if not current_source_name:
             logger.error("No active source found in the current scene.")
             return None
+        # version = client.send("GetVersion", raw=True)
+        # pprint(version)
+        # responseraw = client.send("GetSourceScreenshot", {"sourceName": current_source_name, "imageFormat": "png", "imageWidth": width, "imageHeight": height, "compressionQuality": compression}, raw=True)
         response = client.get_source_screenshot(name=current_source_name, img_format='png', quality=compression, width=width, height=height)
+        # print(responseraw)
         if response and response.image_data:
             return response.image_data.split(',', 1)[-1]  # Remove data:image/png;base64, prefix if present
         else:
@@ -376,6 +383,38 @@ def get_screenshot_base64(compression=0, width=None, height=None):
     except Exception as e:
         logger.error(f"Error getting screenshot: {e}")
         return None
+    
+
+def get_screenshot_PIL(source_name=None, compression=75, img_format='png', width=None, height=None, retry=3):
+    import io
+    import base64
+    from PIL import Image
+    if not source_name:
+        source_name = get_active_source().get('sourceName', None)
+    if not source_name:
+        logger.error("No active source found in the current scene.")
+        return None
+    while True:
+        response = client.get_source_screenshot(name=source_name, img_format=img_format, quality=compression, width=width, height=height)
+        try:
+            response.image_data = response.image_data.split(',', 1)[-1]  # Remove data:image/png;base64, prefix if present
+        except AttributeError:
+            retry -= 1
+            if retry <= 0:
+                logger.error(f"Error getting screenshot: {response}")
+                return None
+            continue
+        if response and response.image_data:
+            image_data = response.image_data.split(',', 1)[-1]  # Remove data:image/png;base64, prefix if present
+            image_data = base64.b64decode(image_data)
+            img = Image.open(io.BytesIO(image_data)).convert("RGBA")
+        # if width and height:
+            # img = img.resize((width, height), Image.Resampling.LANCZOS)
+            return img
+    return None
+
+    
+    
 
 def update_current_game():
     gsm_state.current_game = get_current_scene()
@@ -425,6 +464,47 @@ def main():
     disconnect_from_obs()
 
 if __name__ == '__main__':
+    from mss import mss
     logging.basicConfig(level=logging.INFO)
-    main()
+    # main()
+    connect_to_obs_sync()
+    # i = 100
+    # for i in range(1, 100):
+    #     print(f"Getting screenshot {i}")
+    #     start = time.time()
+    # # get_screenshot(compression=95)
+    # # get_screenshot_base64(compression=95, width=1280, height=720)
+    
+    #     img = get_screenshot_PIL(compression=i, img_format='jpg', width=1280, height=720)
+    #     end = time.time()
+    #     print(f"Time taken to get screenshot with compression {i}: {end - start} seconds")
+        
+    # for i in range(1, 100):
+    #     print(f"Getting screenshot {i}")
+    #     start = time.time()
+    # # get_screenshot(compression=95)
+    # # get_screenshot_base64(compression=95, width=1280, height=720)
+    
+    #     img = get_screenshot_PIL(compression=i, img_format='jpg', width=2560, height=1440)
+    #     end = time.time()
+    #     print(f"Time taken to get screenshot full sized jpg with compression {i}: {end - start} seconds")
+
+    # png_img = get_screenshot_PIL(compression=75, img_format='png', width=1280, height=720)
+
+    # jpg_img = get_screenshot_PIL(compression=100, img_format='jpg', width=2560, height=1440)
+
+    # png_img.show()
+    # jpg_img.show()
+    
+    # start = time.time()
+    # with mss() as sct:
+    #     monitor = sct.monitors[1]
+    #     sct_img = sct.grab(monitor)
+    #     img = Image.frombytes('RGB', sct_img.size, sct_img.bgra, 'raw', 'BGRX')
+    #     img.show()
+    # end = time.time()
+    # print(f"Time taken to get screenshot with mss: {end - start} seconds")
+
+    
+    # print(get_screenshot_base64(compression=75, width=1280, height=720))
 
